# This file is part of the RadiusRB library for Ruby.
# Copyright (C) 2012 Davide Guerri <davide.guerri@gmail.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

module RadiusRB

  class VendorCollection < Array

    def initialize
      @collection = {}
      @revcollection = []
    end

    def add(id, name)
      @collection[name] ||= Vendor.new(name, id)
      @revcollection[id.to_i] ||= @collection[name]
      self << @collection[name]
    end

    def find_by_name(name)
      @collection[name]
    end

    def find_by_id(id)
      @revcollection[id.to_i]
    end

  end

  class Vendor

    include RadiusRB

    attr_reader :name, :id

    def initialize(name, id)
      @name = name
      @id = id
      @attributes = AttributesCollection.new self
    end

    def add_attribute(name, id, type)
      @attributes.add(name, id, type)
    end

    def find_attribute_by_name(name)
      @attributes.find_by_name(name)
    end

    def find_attribute_by_id(id)
      @attributes.find_by_id(id.to_i)
    end

    def has_attributes?
      !@attributes.empty?
    end

    def attributes
      @attributes
    end

  end

end
